<?php
/**
 * Class Custom Email Sender Admin
 * The admin-specific functionality of the plugin
 *
 * @author NeosLab <contact@neoslab.com>
 * @link https://neoslab.com
 * @version 2.2.6
 * @package Custom_Email_Sender
*/
class Custom_Email_Sender_Admin
{
	/**
	 * The ID of this plugin
	*/
	private $plugin_name;

	/**
	 * The version of this plugin
	*/
	private $version;

	/**
	 * Initialize the class and set its properties
	*/
	public function __construct($plugin_name, $version)
	{
		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the dashboard area
	*/
	public function enqueue_backend_standalone()
	{
		wp_register_style($this->plugin_name.'-standalone', plugin_dir_url(__FILE__).'assets/styles/standalone.css', array(), $this->version, 'all');
		wp_enqueue_style($this->plugin_name.'-standalone');
	}

	/**
	 * Register the stylesheets for the admin area
	*/
	public function enqueue_backend_styles()
	{
		wp_register_style($this->plugin_name.'-fontawesome', plugin_dir_url(__FILE__).'assets/styles/fontawesome.min.css', array(), $this->version, 'all');
		wp_register_style($this->plugin_name.'-dashboard', plugin_dir_url(__FILE__).'assets/styles/dashboard.css', array(), $this->version, 'all');
		wp_enqueue_style($this->plugin_name.'-fontawesome');
		wp_enqueue_style($this->plugin_name.'-dashboard');
	}

	/**
	 * Register the JavaScript for the admin area
	*/
	public function enqueue_backend_scripts()
	{
		wp_register_script($this->plugin_name.'-script', plugin_dir_url(__FILE__).'assets/javascripts/script.js', array('jquery'), $this->version, false);
		wp_enqueue_script($this->plugin_name.'-script');
	}

	/**
	 * Return the plugin header
	*/
	public function return_plugin_header()
	{
		$html = '<div class="header-plugin"><span class="header-icon"><i class="fas fa-sliders-h"></i></span> <span class="header-text">'.__('Custom Email Sender', 'custom-email-sender').'</span></div>';
		return $html;
	}

	/**
	 * Return the tabs menu
	*/
	public function return_tabs_menu($tab)
	{
		$link = admin_url('options-general.php');
		$list = array
		(
			array('tab1', 'custom-email-sender-admin', 'fa-cogs', __('Settings', 'custom-email-sender')),
			array('tab2', 'custom-email-sender-about', 'fa-info-circle', __('About', 'custom-email-sender'))
		);

		$menu = null;
		foreach($list as $item => $value)
		{
			$menu ='<div class="tab-label '.$value[0].' '.(($tab == $value[0]) ? 'active' : '').'"><a href="'.$link.'?page='.$value[1].'"><i class="fas '.$value[2].'"></i> <span>'.$value[3].'</span></a></div>';
			echo $menu;
		}
	}

	/**
 	 * Return Email Address
	*/
	public function return_sender_email($old)
	{
		$opts = get_option('_custom_email_sender');

		if((isset($opts['sender-email'])) && (!empty($opts['sender-email'])) && ($opts['sender-email'] !== null))
		{
			return $opts['sender-email'];
		}
		else
		{
			return get_option('admin_email');
		}
	}

	/**
	 * Return Email Sender
	*/
	public function return_sender_name($old)
	{
		$opts = get_option('_custom_email_sender');

		if((isset($opts['sender-name'])) && (!empty($opts['sender-name'])) && ($opts['sender-name'] !== null))
		{
			return $opts['sender-name'];
		}
		else
		{
			return get_option('blogname');
		}
	}

	/**
	 * Update `Options` on form submit
	*/
	public function return_update_options()
	{
		if((isset($_POST['ces-update-option'])) && ($_POST['ces-update-option'] == 'true')
		&& check_admin_referer('ces-referer-form', 'ces-referer-option'))
		{
			$opts = array('sender-email' => null, 'sender-name' => null);
			if((isset($_POST['_custom_email_sender']['sender-email']))
			&& (isset($_POST['_custom_email_sender']['sender-name'])))
			{
				$opts['sender-email'] = sanitize_email($_POST['_custom_email_sender']['sender-email']);
				if(is_email($opts['sender-email']) == false)
				{
					header('location:'.admin_url('options-general.php?page=custom-email-sender-admin').'&status=error&type=email');
					die();
				}

				$opts['sender-name'] = sanitize_text_field($_POST['_custom_email_sender']['sender-name']);
				if((empty($opts['sender-name'])) || (strlen($opts['sender-name']) < 3))
				{
					header('location:'.admin_url('options-general.php?page=custom-email-sender-admin').'&status=error&type=sender');
					die();
				}

				$data = update_option('_custom_email_sender', $opts);
				header('location:'.admin_url('options-general.php?page=custom-email-sender-admin').'&status=updated');
				die();
			}
			else
			{
				header('location:'.admin_url('options-general.php?page=custom-email-sender-admin').'&status=error&type=unknown');
				die();
			}
		}
	}

	/**
	 * Return the `Options` page
	*/
	public function return_options_page()
	{
		$opts = get_option('_custom_email_sender');

		if((isset($_GET['status'])) && ($_GET['status'] == 'updated'))
		{
			$notice = array('success', __('Your settings have been successfully updated.', 'custom-email-sender'));
		}
		elseif((isset($_GET['status'])) && ($_GET['status'] == 'error'))
		{
			if((isset($_GET['type'])) && ($_GET['type'] == 'email'))
			{
				$notice = array('error', __('Your email address is not valid !!', 'custom-email-sender'));
			}
			elseif((isset($_GET['type'])) && ($_GET['type'] == 'sender'))
			{
				$notice = array('error', __('Your sender name is not valid !!', 'custom-email-sender'));
			}
			elseif((isset($_GET['type'])) && ($_GET['type'] == 'unknown'))
			{
				$notice = array('error', __('An unknown error occured !!', 'custom-email-sender'));
			}
		}

		?>
		<div class="wrap">
			<section class="wpbnd-wrapper">
				<div class="wpbnd-container">
					<div class="wpbnd-tabs">
						<?php echo $this->return_plugin_header(); ?>
						<main class="tabs-main">
							<?php echo $this->return_tabs_menu('tab1'); ?>
							<section class="tab-section">
								<?php if(isset($notice)) { ?>
								<div class="wpbnd-notice <?php echo $notice[0]; ?>">
									<span class="close-btn" onclick="this.parentElement.style.display='none';">&times;</span>
									<span><?php echo _e($notice[1], 'custom-email-sender'); ?></span>
								</div>
								<?php } elseif((!isset($opts['sender-name'])) || (!isset($opts['sender-email']))) { ?>
								<div class="wpbnd-notice warning">
									<span class="close-btn" onclick="this.parentElement.style.display='none';">&times;</span>
									<span><?php echo _e('You have not set up your sender name and email address ! In order to do so, please use the below form.', 'custom-email-sender'); ?></span>
								</div>
								<?php } else { ?>
								<div class="wpbnd-notice info">
									<span class="close-btn" onclick="this.parentElement.style.display='none';">&times;</span>
									<span><?php echo _e('Your plugin is properly configured ! You can change at anytime your sender name and email address using the below form.', 'custom-email-sender'); ?></span>
								</div>
								<?php } ?>
								<form method="POST">
									<input type="hidden" name="ces-update-option" value="true" />
									<?php wp_nonce_field('ces-referer-form', 'ces-referer-option'); ?>
									<div class="wpbnd-form">
										<div class="field">
											<?php $fieldID = uniqid(); ?>
											<span class="label"><?php echo _e('Sender Name', 'custom-email-sender'); ?><span class="redmark">(<span>*</span>)</span></span>
											<input type="text" id="<?php echo $fieldID; ?>" name="_custom_email_sender[sender-name]" placeholder="<?php echo _e('Enter your sender name', 'custom-email-sender'); ?>" value="<?php if(isset($opts['sender-name'])) { echo stripslashes($opts['sender-name']); } ?>" autocomplete="OFF" required="required" />
											<small><?php echo _e('Enter the sender name as you want it to appear when email are sent by your backend (Min. 3 characters).', 'custom-email-sender'); ?></small>
										</div>
										<div class="field">
											<?php $fieldID = uniqid(); ?>
											<span class="label"><?php echo _e('Sender Email', 'custom-email-sender'); ?><span class="redmark">(<span>*</span>)</span></span>
											<input type="email" id="<?php echo $fieldID; ?>" name="_custom_email_sender[sender-email]" placeholder="<?php echo _e('Enter your email address', 'custom-email-sender'); ?>" value="<?php if(isset($opts['sender-email'])) { echo sanitize_email($opts['sender-email']); } ?>" autocomplete="OFF" required="required" />
											<small><?php echo _e('Enter the sender email as you want it to appear when email are sent by your backend (Must be a valid email address).', 'custom-email-sender'); ?></small>
										</div>
										<div class="form-footer">
											<input type="submit" class="button button-primary button-theme" style="height:45px;" value="<?php _e('Update Settings', 'custom-email-sender'); ?>">
										</div>
									</div>
								</form>
							</section>
						</main>
					</div>
				</div>
			</section>
		</div>
		<?php
	}

	/**
	 * Return the `About` page
	*/
	public function return_about_page()
	{
		?>
		<div class="wrap">
			<section class="wpbnd-wrapper">
				<div class="wpbnd-container">
					<div class="wpbnd-tabs">
						<?php echo $this->return_plugin_header(); ?>
						<main class="tabs-main">
							<?php echo $this->return_tabs_menu('tab2'); ?>
							<section class="tab-section">
								<div class="about-wrapper">
									<div class="about-plugins"><h4><i class="fas fa-laptop-code"></i> <?php echo _e('Discover all our available plugins', 'custom-email-sender'); ?></h4></div>
									<table class="plugins-table">
										<tbody>
											<?php
											$items = array
											(
												array
												(
													'name' => 'Custom Email Sender',
													'base' => 'custom-email-sender',
													'vers' => '2.2.6',
													'date' => '2021-08-25',
													'test' => '5.8',
													'lang' => 'English, French, Spanish'
												),
												array
												(
													'name' => 'Database Toolset',
													'base' => 'database-toolset',
													'vers' => '1.5.6',
													'date' => '2021-08-25',
													'test' => '5.8',
													'lang' => 'English, French, Spanish'
												),
												array
												(
													'name' => 'Medias Toolbox',
													'base' => 'medias-toolbox',
													'vers' => '1.5.0',
													'date' => '2021-08-25',
													'test' => '5.8',
													'lang' => 'English, French, Spanish'
												),
												array
												(
													'name' => 'Powered Minifier',
													'base' => 'powered-minifier',
													'vers' => '1.5.0',
													'date' => '2021-08-25',
													'test' => '5.8',
													'lang' => 'English, French, Spanish'
												)
											);

											foreach($items as $item)
											{
												$table = '<tr>';
												$table.= '<td width="160px" scope="col"><a class="thumb" ref="nofollow noreferrer noopener" target="_blank" href="https://wordpress.org/plugins/'.$item['base'].'/"><img src="https://ps.w.org/'.$item['base'].'/assets/icon-256x256.png" alt="logo"/></a></td>';
												$table.= '<td scope="col">';
												$table.= '<ul class="plugin-details">';
												$table.= '<li>'.__('Plugin', 'polygon').' : <strong>'.$item['name'].'</strong></li>';
												$table.= '<li>'.__('Version', 'polygon').' : <strong>'.$item['vers'].'</strong></li>';
												$table.= '<li>'.__('Last release', 'polygon').' : <strong>'.$item['date'].'</strong></li>';
												$table.= '<li>'.__('Wordpress Version', 'polygon').' : <strong>'.$item['test'].'</strong></li>';
												$table.= '<li>'.__('Languages', 'polygon').' : <strong>'.$item['lang'].'</strong></li>';
												$table.= '<li><a ref="nofollow noreferrer noopener" target="_blank" href="https://wordpress.org/plugins/'.$item['base'].'/">'.__('Visit on Wordpress.org', 'polygon').'</a></li>';
												$table.= '</ul>';
												$table.= '</td>';
												$table.= '</tr>';
												echo $table;
											}
											?>
										</tbody>
									</table>
								</div>
							</section>
						</main>
					</div>
				</div>
			</section>
		</div>
		<?php
	}

	/**
	 * Return Backend Menu
	*/
	public function return_admin_menu()
	{
		add_options_page('Custom Email Sender', 'Custom Email Sender', 'manage_options', 'custom-email-sender-admin', array($this, 'return_options_page'));
		add_options_page('Custom Email Sender', 'About', 'manage_options', 'custom-email-sender-about', array($this, 'return_about_page'));
		remove_submenu_page('options-general.php', 'custom-email-sender-about');
	}
}

?>
